@@ -25,17 +25,19 @@ void _get_distances(int sites[], int & len, int distances[]) {
 void _get_distances(std::vector<int> sites, std::vector<int> & distances) {
     int size = sites.size();
     int len = ((size - 1) * size) / 2;
-    int sites_array[size];
+    int * sites_array = new int[size];
     for (int i=0; i<size; i++) {
         sites_array[i] = sites[i];
     }
-    int dist_array[len];
+    int * dist_array = new int[len];
     _get_distances(sites_array, size, dist_array);
     distances.resize(len);
     
     for (int i=0; i<len; i++) {
         distances[i] = dist_array[i];
     }
+    delete[] sites_array;
+    delete[] dist_array;
 }
 
 // check if any value in an vector is zero
@@ -107,7 +109,7 @@ double _geomean_large(int distances[], int & len) {
         return ans;
     };
 
-    const int bucket_size = -std::log2(std::numeric_limits<double>::min());
+    const int bucket_size = (int)-std::log2(std::numeric_limits<double>::min());
     std::size_t buckets = len / bucket_size;
 
     double invN = 1.0 / len;
@@ -152,8 +154,8 @@ std::vector<double> _simulate_distribution(Chooser & choices, int iterations,
     std::vector<double> mean_distances(iterations);
     
     int distance_len = (de_novo_count - 1) * (de_novo_count) / 2;
-    int distances[distance_len];
-    int positions[de_novo_count];
+    int * distances = new int[distance_len];
+    int * positions = new int[de_novo_count];
     // run through the required iterations
     for (int n=0; n < iterations; n++) {
         // randomly select de novo sites for the iteration
@@ -167,11 +169,8 @@ std::vector<double> _simulate_distribution(Chooser & choices, int iterations,
         
         mean_distances[n] = _geomean(distances, distance_len);
     }
-    
-    // make sure the mean distances are sorted, so we can quickly merge with
-    // previous distances
-    std::sort(mean_distances.begin(), mean_distances.end());
-    
+    delete[] distances;
+    delete[] positions;
     return mean_distances;
 }
 
@@ -210,29 +209,23 @@ double _analyse_de_novos(Chooser & choices, int iterations, int de_novo_count,
     double minimum_prob = 1.0/(1.0 + static_cast<double>(iterations));
     double sim_prob = minimum_prob;
     std::vector<double> dist;
-    
+
+    std::uint32_t n_smaller = 0;
     while (iterations < 100000000 && sim_prob == minimum_prob) {
         int iters_to_run = iterations - dist.size();
         
         minimum_prob = 1.0/(1.0 + static_cast<double>(iterations));
         
         // simulate mean distances between de novos
-        std::vector<double> new_dist = _simulate_distribution(choices,
-            iters_to_run, de_novo_count);
+        dist = _simulate_distribution(choices, iters_to_run, de_novo_count);
         
-        // merge the two sorted lists into a sorted vector
-        std::vector<double> v(iterations);
-        std::merge(dist.begin(), dist.end(), new_dist.begin(), new_dist.end(),
-            v.begin());
-        dist = v;
+        for (auto &x : dist) {
+            n_smaller += (x <= observed_value);
+        }
         
-        // figure out where in the list a random probability would fall
-        std::vector<double>::iterator pos;
-        pos = std::upper_bound(dist.begin(), dist.end(), observed_value);
-        double position = pos - dist.begin();
-        
-        // estimate the probability from the position
-        sim_prob = (1.0 + position)/(1.0 + dist.size());
+        // estimate the probability from the number of times a random distance
+        // is equal to or smaller than the observed value
+        sim_prob = (1.0 + (double)n_smaller) / (1.0 + (double)iterations);
         
         // halt permutations if the P value could never be significant
         double z = 10.0;
