@@ -27,7 +27,7 @@ from pathlib import Path
 from denovonear.load_gene import cds_length, construct_gene_object, \
     get_de_novos_in_transcript, get_transcript_ids, load_gene, \
     count_de_novos_per_transcript, minimise_transcripts
-from denovonear.transcript import Transcript
+from gencodegenes.transcript import Transcript
 from denovonear.rate_limiter import RateLimiter
 
 async def call(func, *args, **kwargs):
@@ -37,7 +37,7 @@ async def call(func, *args, **kwargs):
         return await func(ensembl, *args, **kwargs)
 
 def _run(func, *args, **kwargs):
-    return asyncio.get_event_loop().run_until_complete(call(func, *args, **kwargs))
+    return asyncio.run(call(func, *args, **kwargs))
 
 class TestLoadGenePy(unittest.TestCase):
     """ unit test functions to load genes
